mgkit.snps package
==================

Submodules
----------

.. toctree::

   mgkit.snps.classes
   mgkit.snps.conv_func
   mgkit.snps.filter
   mgkit.snps.funcs
   mgkit.snps.mapper

Module contents
---------------

.. automodule:: mgkit.snps
   :members:
   :undoc-members:
   :show-inheritance:
